@@ -55,11 +55,11 @@ from grokcore.annotation import Annotation
 
 from grokcore.site import LocalUtility
 from grokcore.site import Site
+from grokcore.site import getApplication
 from grokcore.site import local_utility
 
 from zope.event import notify
 from zope.site.hooks import getSite
-from grok.util import getApplication
 from zope.lifecycleevent import (
     IObjectCreatedEvent, ObjectCreatedEvent,
     IObjectModifiedEvent, ObjectModifiedEvent,
@@ -81,17 +81,22 @@ from zope.container.contained import (
     ContainerModifiedEvent)
 
 from grok.events import ApplicationInitializedEvent
+
 from grok.components import Application
 from grok.components import View, Form, AddForm, EditForm, DisplayForm
+from grok.components import ExceptionView, NotFoundView, UnauthorizedView
 from grok.components import XMLRPC, REST, JSON
-from grok.components import Traverser
 from grok.components import Indexes
 from grok.components import Role
+
+from grokcore.traverser import Traverser
+
 from grok.interfaces import IRESTSkinType, IRESTLayer
 from grok.interfaces import IApplicationInitializedEvent
 
+from grokcore.traverser import traversable
 from grok.directive import (
-    permissions, site, restskin, traversable)
+    permissions, site, restskin)
 
 # BBB These two functions are meant for test fixtures and should be
 # imported from grok.testing, not from grok.
