@@ -2,15 +2,11 @@
 Grok allows you to set up catalog indexes in your application with a
 special indexes declaration.
 
-  >>> import grok
-  >>> grok.grok('grok.ftests.catalog.indexes')
-
 Let's set up a site in which we manage a couple of objects::
 
-  >>> from grok.ftests.catalog.indexes import Herd, Herd2, Mammoth
   >>> herd = Herd()
   >>> getRootFolder()['herd'] = herd
-  >>> from zope.app.component.hooks import setSite
+  >>> from zope.site.hooks import setSite
   >>> setSite(herd)
 
 Now we add some indexable objects to the site::
@@ -20,7 +16,7 @@ Now we add some indexable objects to the site::
 
 We are able to query the catalog::
 
-  >>> from zope.app.catalog.interfaces import ICatalog
+  >>> from zope.catalog.interfaces import ICatalog
   >>> from zope.component import getUtility, queryUtility
   >>> catalog = getUtility(ICatalog)
   >>> for obj in catalog.searchResults(name=('Beta', 'Beta')):
@@ -54,10 +50,10 @@ Nuke the catalog and intids in the end, so as not to confuse
 other tests::
 
   >>> sm = herd.getSiteManager()
-  >>> from zope.app.catalog.interfaces import ICatalog
+  >>> from zope.catalog.interfaces import ICatalog
   >>> sm.unregisterUtility(catalog, provided=ICatalog)
   True
-  >>> from zope.app.intid.interfaces import IIntIds
+  >>> from zope.intid.interfaces import IIntIds
   >>> from zope import component
   >>> intids = component.getUtility(IIntIds)
   >>> sm.unregisterUtility(intids, provided=IIntIds)
